@@ -1,14 +1,14 @@
 use 5.014;
 
 package Mojo::UserAgent::Mockable::Serializer;
-$Mojo::UserAgent::Mockable::Serializer::VERSION = '1.01';
+$Mojo::UserAgent::Mockable::Serializer::VERSION = '1.02';
 use warnings::register;
 
 use Carp;
 use Class::Load ':all';
 use Data::Serializer::Raw;
 use English qw/-no_match_vars/;
-use File::Slurp qw/slurp write_file/;
+use File::Slurper qw(write_text read_text);
 use JSON::MaybeXS qw/encode_json decode_json/;
 use Mojo::Base 'Mojo::EventEmitter';
 use Safe::Isa (qw/$_isa/);
@@ -171,13 +171,13 @@ sub store {
     my ($self, $file, @transactions) = @_;
 
     my $serialized = $self->serialize(@transactions);
-    write_file($file, $serialized);
+    write_text($file, $serialized);
 }
 
 sub retrieve {
     my ($self, $file) = @_;
 
-    my $contents = slurp($file);
+    my $contents = read_text($file);
     return $self->deserialize($contents);
 }
 1;
@@ -194,7 +194,7 @@ Mojo::UserAgent::Mockable::Serializer - A class that serializes Mojo transaction
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -203,6 +203,7 @@ version 1.01
     
     use Mojo::UserAgent::Mockable::Serializer;
     use Mojo::UserAgent;
+    use File::Slurper qw(read_text write_text);
 
     my $ua = Mojo::UserAgent->new;
     my $serializer = Mojo::UserAgent::Mockable::Serializer->new;
@@ -213,7 +214,7 @@ version 1.01
     push @transactions, $ua->get('http://example.com/subobject/456');
 
     my $json = $serializer->serialize(@transactions);
-    write_file('/path/to/file.json', $json);
+    write_text('/path/to/file/json', $json);
 
     # OR
 
@@ -221,7 +222,7 @@ version 1.01
 
     # Later...
 
-    my $json = read_file('/path/to/file.json');
+    my $json = read_text('/path/to/file.json');
     my @reconstituted_transactions = $serializer->deserialize($json);
 
     # OR
